==> jc-1.4.0.tar.gz: soot/tagkit/LineNumberTag.h <==
// public class soot.tagkit.LineNumberTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 613215cfda24633d soot_tagkit_LineNumberTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_LineNumberTag_H_
#define _JC_soot_tagkit_LineNumberTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_LineNumberTag$sub_refs	_jc_soot_tagkit_LineNumberTag$sub_refs;
typedef struct _jc_soot_tagkit_LineNumberTag$sub_nonrefs	_jc_soot_tagkit_LineNumberTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_LineNumberTag$refs	_jc_soot_tagkit_LineNumberTag$refs;
typedef struct _jc_soot_tagkit_LineNumberTag$nonrefs	_jc_soot_tagkit_LineNumberTag$nonrefs;
typedef struct _jc_soot_tagkit_LineNumberTag$object	_jc_soot_tagkit_LineNumberTag$object;

typedef const struct _jc_soot_tagkit_LineNumberTag$vmethods	_jc_soot_tagkit_LineNumberTag$vmethods;
typedef const struct _jc_soot_tagkit_LineNumberTag$vtable	_jc_soot_tagkit_LineNumberTag$vtable;
typedef const struct _jc_soot_tagkit_LineNumberTag$vtype	_jc_soot_tagkit_LineNumberTag$vtype;

// Constructors
extern void _jc_soot_tagkit_LineNumberTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *, jint);

// Virtual methods
extern jint _jc_soot_tagkit_LineNumberTag$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LineNumberTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *);
extern _jc_byte_array *_jc_soot_tagkit_LineNumberTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *);
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LineNumberTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_LineNumberTag$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_soot_tagkit_LineNumberTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_LineNumberTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_LineNumberTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_LineNumberTag$vmethods {
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *);
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *);
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *);
};

// Vtable
struct _jc_soot_tagkit_LineNumberTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_LineNumberTag$vmethods	soot_tagkit_LineNumberTag;
};

// Vtype
struct _jc_soot_tagkit_LineNumberTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_LineNumberTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_LineNumberTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_LineNumberTag$refs {
    _jc_soot_tagkit_LineNumberTag$sub_refs	soot_tagkit_LineNumberTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_LineNumberTag$sub_nonrefs {
	jint	line__5fnumber;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_LineNumberTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_LineNumberTag$sub_nonrefs	soot_tagkit_LineNumberTag;
};

// Object instance structure
struct _jc_soot_tagkit_LineNumberTag$object {
	_jc_soot_tagkit_LineNumberTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_LineNumberTag$vtype	*vtype;
	_jc_soot_tagkit_LineNumberTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_LineNumberTag$vtype _jc_soot_tagkit_LineNumberTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_LineNumberTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_LineNumberTag$class_object;

#endif	/* _JC_soot_tagkit_LineNumberTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/LineNumberTag.h <==
// public class soot.tagkit.LineNumberTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 613215cfda24633d soot_tagkit_LineNumberTag

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_LineNumberTag_H_
#define _JC_soot_tagkit_LineNumberTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_soot_tagkit_LineNumberTag$sub_refs	_jc_soot_tagkit_LineNumberTag$sub_refs;
typedef struct _jc_soot_tagkit_LineNumberTag$sub_nonrefs	_jc_soot_tagkit_LineNumberTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_LineNumberTag$refs	_jc_soot_tagkit_LineNumberTag$refs;
typedef struct _jc_soot_tagkit_LineNumberTag$nonrefs	_jc_soot_tagkit_LineNumberTag$nonrefs;
typedef struct _jc_soot_tagkit_LineNumberTag$object	_jc_soot_tagkit_LineNumberTag$object;

typedef const struct _jc_soot_tagkit_LineNumberTag$vmethods	_jc_soot_tagkit_LineNumberTag$vmethods;
typedef const struct _jc_soot_tagkit_LineNumberTag$vtable	_jc_soot_tagkit_LineNumberTag$vtable;
typedef const struct _jc_soot_tagkit_LineNumberTag$vtype	_jc_soot_tagkit_LineNumberTag$vtype;

// Constructors
extern void _jc_soot_tagkit_LineNumberTag$method$_init$7f1776288300b98d(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_soot_tagkit_LineNumberTag$method$getLineNumber$fae6c5f943e25d60(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LineNumberTag$method$getName$bec186f2ce7e1882(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *) _JC_JCNI_ATTR;
extern _jc_byte_array *_jc_soot_tagkit_LineNumberTag$method$getValue$824c7561d2f47329(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_LineNumberTag$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_LineNumberTag$method_info$getLineNumber$fae6c5f943e25d60;
extern _jc_method _jc_soot_tagkit_LineNumberTag$method_info$getName$bec186f2ce7e1882;
extern _jc_method _jc_soot_tagkit_LineNumberTag$method_info$getValue$824c7561d2f47329;
extern _jc_method _jc_soot_tagkit_LineNumberTag$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_tagkit_LineNumberTag$vmethods {
	jint	(*getLineNumber$fae6c5f943e25d60)(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getName$bec186f2ce7e1882)(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *) _JC_JCNI_ATTR;
	_jc_byte_array	*(*getValue$824c7561d2f47329)(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_tagkit_LineNumberTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_LineNumberTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_LineNumberTag$vmethods	soot_tagkit_LineNumberTag;
};

// Vtype
struct _jc_soot_tagkit_LineNumberTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_LineNumberTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_LineNumberTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_LineNumberTag$refs {
    _jc_soot_tagkit_LineNumberTag$sub_refs	soot_tagkit_LineNumberTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_LineNumberTag$sub_nonrefs {
	jint	line__5fnumber;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_LineNumberTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_LineNumberTag$sub_nonrefs	soot_tagkit_LineNumberTag;
};

// Object instance structure
struct _jc_soot_tagkit_LineNumberTag$object {
	_jc_soot_tagkit_LineNumberTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_LineNumberTag$vtype	*vtype;
	_jc_soot_tagkit_LineNumberTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_LineNumberTag$vtype _jc_soot_tagkit_LineNumberTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_LineNumberTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_LineNumberTag$class_object;

#endif	/* _JC_soot_tagkit_LineNumberTag_H_ */
